Before coding
=============

Thinks and tips to know before coding

Unit testing
------------

`Nose2 <https://github.com/nose-devs/nose2>`_ is used on this project.
Don't forget to write and maintain unit tests.

Unit tests are in ./tests directory.


